# -*- coding: utf-8 -*-
import law
import luigi
import logging
import os
import re

from functools import partial

from .FastWarm import FastWarm
from ..util import working_directory

from analysis.framework import Task, SpaceSeparatedListParameter

logger = logging.getLogger(__name__)
working_directory = partial(working_directory, logger=logger)


class CopyFastWarm(Task, law.LocalWorkflow):
    force = luigi.BoolParameter(default=False)

    warm_dir = luigi.Parameter(default='warmups')

    channels = SpaceSeparatedListParameter(
        cls=luigi.Parameter,
        choices=("LO", "R", "V", "RRa", "RRb", "RV", "VV")
    )

    def create_branch_map(self):
        """Branch data dicts. Each branch should correspond to exactly one output."""
        return FastWarm.req(self).branch_map

    def workflow_requires(self):
        if self.force:
            return {"fastwarm": FastWarm.req(self, acceptance=0)}
        else:
            return {"fastwarm": FastWarm.req(self)}

    def output(self):
        basename = FastWarm(branch=self.branch).output().basename
        outfile = re.sub('.gz$', '', basename)
        outfile = re.sub('.tar$', '', outfile) + '.log'
        return law.LocalFileTarget(
            '{}/{}/{}/{}'.format(
                self.warm_dir, 'fastwarm', self.name, outfile
            )
        )

    def run(self):
        self.output().parent.touch()
        with working_directory(self.output().parent.path):
            inp = FastWarm(branch=self.branch).output()
            if not inp.exists():
                logger.warning('FastWarm result not found: %s (branch %s)', inp, self.branch)
            else:
                logger.info('Copying FastWarm result: %s', inp)
                inp.load('')
