# -*- coding: utf-8 -*-
import law
import luigi
import logging
import os
import re

from functools import partial

from .MergeFastWarm import MergeFastWarm
from ..util import working_directory

from analysis.framework import Task

logger = logging.getLogger(__name__)
working_directory = partial(working_directory, logger=logger)


class CopyMergeFastWarm(Task, law.LocalWorkflow):
    warm_dir = luigi.Parameter(default='warmups')

    observables = luigi.ListParameter()

    def create_branch_map(self):
        """Branch data dicts. Each branch should correspond to exactly one output."""
        return {
            i : {'observable': obs}
            for i, obs in enumerate(self.observables)
        }

    def workflow_requires(self):
        return {'mergefastwarm': MergeFastWarm()}

    def output(self):
        return law.LocalFileTarget(
            '{}/{}/{}/{}.{}.wrm'.format(
                self.warm_dir, 'mergefastwarm', self.name, self.process,
                self.branch_data['observable'],
            )
        )

    def run(self):
        self.output().parent.touch()
        with working_directory(self.output().parent.path):
            inp = MergeFastWarm().output()
            if not inp.exists():
                logger.warning('MergeFastWarm result not found: %s (branch %s)', inp, self.branch)
            else:
                logger.info('Copying MergeFastWarm result: %s', inp)
                inp.load('')
