import logging
import os
import six

from contextlib import contextmanager
from law.util import colored

logger = logging.getLogger(__name__)


def pretty_print_command(command_spec, color='yellow'):
    """Pretty-print a long command across multiple lines."""
    _cmd = command_spec
    if isinstance(_cmd, tuple) or isinstance(_cmd, list):
        _cmd = ' '.join(_cmd)
    # put -/-- arguments on their own line
    _cmd = re.sub(r'^([^\s]+)', '\\1 \\\n  ', _cmd)
    _cmd = re.sub(r'(?<= )-', '\\\n  -', _cmd)
    print(colored(_cmd, color=color))


@contextmanager
def working_directory(dirname, logger=logger):
    """Context manager for temporarily switching to another working directory."""

    old_dir = os.getcwd()
    logger.debug("Temporarily switching into directory: %s", dirname)
    os.chdir(dirname)
    try:
        yield
    finally:
        logger.debug("Switching back to directory: %s", old_dir)
        os.chdir(old_dir)


def createRuncard(baseRuncard, params):

    if (params['channel'] == 'RRa'):
        channel = 'RR'
        region = 'a'
    elif (params['channel'] == 'RRb'):
        channel = 'RR'
        region = 'b'
    else:
        channel = params['channel']
        region = 'all'

    substitutions = {
        '@SEED@': params['seed'],
        '@WARMUP@': params['warmup'],
        '@PRODUCTION@': params['production'],
        '@EVENTS@': params['events'],
        '@ITERATIONS@': params['iterations'],
        '@FULLCHANNEL@': params['channel'],
        '@CHANNEL@': channel,
        '@REGION@': region,
        '@UNIT_PHASE@': params['unit_phase']
    }

    data = baseRuncard

    for key, value in six.iteritems(substitutions):
        data = data.replace(key, str(value))

    return data
